@@ -1,7 +1,9 @@
+import os
 
 def get_aws_client(module, with_error=False, params={}):
     from metaflow.exception import MetaflowException
     import requests
+    os.environ['AWS_PROFILE'] = 'aero'
 
     try:
         import boto3
